@@ -156,7 +156,7 @@ if __name__ == '__main__':
                 elif len(callstr.split(':')) == 5:
                     toolname, callencode, callfn, cutoff1, cutoff2 = callstr.split(':')
                     cutoff1 = float(cutoff1)
-                    cutoff2 = float(cutoff1)
+                    cutoff2 = float(cutoff2)
                     score_cutoff = (cutoff1, cutoff2)
             except:
                 raise Exception(f"--calls params is not correct: {callstr}")
@@ -240,7 +240,7 @@ if __name__ == '__main__':
             elif len(callstr.split(':')) == 5:
                 toolname, callencode, callfn, cutoff1, cutoff2 = callstr.split(':')
                 cutoff1 = float(cutoff1)
-                cutoff2 = float(cutoff1)
+                cutoff2 = float(cutoff2)
                 score_cutoff = (cutoff1, cutoff2)
         except:
             raise Exception(f"--calls params is not correct: {callstr}")
@@ -272,6 +272,7 @@ if __name__ == '__main__':
 
     for key in ontcall_tools_dict.keys():
         logger.debug(f"tool={key}, sites={ontcall_tools_dict[key]}")
+
     save_done_file(out_dir)
     logger.info(f"Memory report: {get_current_memory_usage()}")
-    logger.info("TSS unified format generation DONE")
+    logger.info("### TSS unified format generation DONE")
